--[[---------------------------------------
	VARIABLE CACHING
-----------------------------------------]]

-- Lua Functions
local pairs, select, unpack = pairs, select, unpack
-- WoW API Functions / Variables
local GetProfessions,GetProfessionInfo = GetProfessions,GetProfessionInfo

local ATP, Ace3, LSM = unpack(select(2,...))

local herbalism_options

local function GetHerbalismOptions()
	if (not herbalism_options) then
		local db = Ace3.db.profile
		
		herbalism_options = {
			type = "group",
			order = 0,
			name = "",
			desc = '',
			args = {
				copyFrom = {
					order = 1,
					type = "select",
					name = "Copy From: ",
					disabled = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							return false
						else
							return true
						end
					end,
					hidden = function()
						local prof1,prof2 = GetProfessions()
						
						if (Ace3:GetNumActiveProfessions() >= 1 and (prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							return false
						else
							return true
						end
					end,
					set = function(this,value)
						Ace3:CopyValues(db.continents,'herbalism',value)
					end,
					values = function()
						local values = {}
						local prof1,prof2,_,fishing = GetProfessions()
		
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							values["mining"] = "Mining"
						end
						
						if (fishing) then
							values["fishing"] = "Fishing"
						end
						
						values["pets"] = "Pets"
						return values
					end,
					width = "1",
				},
				spacer = {
					type = "description",
					name = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							return " "
						else
							return "|cFFFF7777You do not have Herbalism currently learned.|r"
						end
					end,
					order = 2,
				},
				tabs = {
					type = "group",
					order = 3,
					name = "Continents",
					desc = '',
					hidden = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							return false
						else
							return true
						end
					end,
					args = Ace3:SetupContinentTabs(db,"herbalism"),
				},
			},
		}
	end
	
	return herbalism_options
end

local mining_options

local function GetMiningOptions()
	if (not mining_options) then
		local db = Ace3.db.profile

		mining_options = {
			type = "group",
			order = 0,
			name = "",
			desc = '',
			args = {
				copyFrom = {
					order = 1,
					type = "select",
					name = "Copy From: ",
					disabled = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							return false
						else
							return true
						end
					end,
					hidden = function()
						local prof1,prof2 = GetProfessions()
						
						if (Ace3:GetNumActiveProfessions() >= 1 and (prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							return false
						else
							return true
						end
					end,
					set = function(this,value)
						Ace3:CopyValues(db.continents,'mining',value)
					end,
					values = function()
						local values = {}
						local prof1,prof2,_,fishing = GetProfessions()
		
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							values["herbalism"] = "Herbalism"
						end
						
						if (fishing) then
							values["fishing"] = "Fishing"
						end
						
						values["pets"] = "Pets"
						
						return values
					end,
					width = "1",
				},
				spacer = {
					type = "description",
					name = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							return " "
						else
							return "|cFFFF7777You do not have Mining currently learned.|r"
						end
					end,
					order = 2,
				},
				tabs = {
					type = "group",
					order = 3,
					name = "Continents",
					desc = '',
					hidden = function()
						local prof1,prof2 = GetProfessions()
						
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							return false
						else
							return true
						end
					end,
					args = Ace3:SetupContinentTabs(db,"mining"),
				},
			},
		}
	end
	
	return mining_options
end

local fishing_options

local function GetFishingOptions()
	if (not fishing_options) then
		local db = Ace3.db.profile
		
		fishing_options = {
			type = "group",
			order = 0,
			name = "",
			desc = '',
			args = {
				copyFrom = {
					order = 1,
					type = "select",
					name = "Copy From: ",
					disabled = function()
						local _,_,_,fishing = GetProfessions()
						
						if (fishing) then
							return false
						else
							return true
						end
					end,
					hidden = function()
						local _,_,_,fishing = GetProfessions()

						if (Ace3:GetNumActiveProfessions() >= 1 and fishing) then
							return false
						else
							return true
						end
					end,
					set = function(this,value)
						Ace3:CopyValues(db.continents,'fishing',value)
					end,
					values = function()
						local values = {}
						local prof1,prof2,_,fishing = GetProfessions()
		
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							values["herbalism"] = "Herbalism"
						end
						
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							values["mining"] = "Mining"
						end
						
						values["pets"] = "Pets"
						
						return values
					end,
					width = "1",
				},
				spacer = {
					type = "description",
					name = function()
						local _,_,_,fishing = GetProfessions()
						
						if (fishing) then
							return " "
						else
							return "|cFFFF7777You do not have Fishing currently learned.|r"
						end
					end,
					order = 2,
				},
				tabs = {
					type = "group",
					order = 3,
					name = "Continents",
					desc = '',
					hidden = function()
						local _,_,_,fishing = GetProfessions()
						
						if (fishing) then
							return false
						else
							return true
						end
					end,
					args = Ace3:SetupContinentTabs(db,"fishing"),
				},
			},
		}
	end
	
	return fishing_options
end

local pet_options

local function GetPetOptions()
	if (not pet_options) then
		local db = Ace3.db.profile
		
		pet_options = {
			type = "group",
			order = 0,
			name = "",
			desc = '',
			args = {
				copyFrom = {
					order = 1,
					type = "select",
					name = "Copy From: ",
					hidden = function()
						if (Ace3:GetNumActiveProfessions() >= 1) then
							return false
						else
							return true
						end
					end,
					set = function(this,value)
						Ace3:CopyValues(db.continents,'pets',value)
					end,
					values = function()
						local values = {}
						local prof1,prof2,_,fishing = GetProfessions()
		
						if ((prof1 and GetProfessionInfo(prof1) == "Herbalism") or (prof2 and GetProfessionInfo(prof2) == "Herbalism")) then
							values["herbalism"] = "Herbalism"
						end
						
						if ((prof1 and GetProfessionInfo(prof1) == "Mining") or (prof2 and GetProfessionInfo(prof2) == "Mining")) then
							values["mining"] = "Mining"
						end
						
						if (fishing) then
							values["fishing"] = "Fishing"
						end
						
						return values
					end,
					width = "1",
				},
				spacer = {
					type = "description",
					name = " ",
					order = 2,
				},
				tabs = {
					type = "group",
					order = 3,
					name = "Continents",
					desc = '',
					args = Ace3:SetupContinentTabs(db,"pets"),
				},
			},
		}
	end
	
	return pet_options
end

function Ace3:SetupOptions()
	local ACFG = LibStub("AceConfigRegistry-3.0")
	local ACD = LibStub("AceConfigDialog-3.0")
	

	ACFG:RegisterOptionsTable("AutoTracker Herbalism", GetHerbalismOptions)
	ACFG:RegisterOptionsTable("AutoTracker Mining", GetMiningOptions)
	ACFG:RegisterOptionsTable("AutoTracker Fishing", GetFishingOptions)
	ACFG:RegisterOptionsTable("AutoTracker Pets", GetPetOptions)
	ACFG:RegisterOptionsTable("AutoTracker Profiles", LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db,true))

	if (not ACD.BlizOptions["AutoTracker Herbalism"]) then
		ACD:AddToBlizOptions("AutoTracker Herbalism", "Herbalism", "AutoTracker")
	end
	
	if (not ACD.BlizOptions["AutoTracker Mining"]) then
		ACD:AddToBlizOptions("AutoTracker Mining", "Mining", "AutoTracker")
	end
	
	if (not ACD.BlizOptions["AutoTracker Fishing"]) then
		ACD:AddToBlizOptions("AutoTracker Fishing", "Fishing", "AutoTracker")
	end
	
	if (not ACD.BlizOptions["AutoTracker Pets"]) then
		ACD:AddToBlizOptions("AutoTracker Pets", "Pets", "AutoTracker")
	end

	if (not ACD.BlizOptions["AutoTracker Profiles"]) then
		ACD:AddToBlizOptions("AutoTracker Profiles", "Profiles", "AutoTracker")
	end
end