-- Lua Functions
local pairs, print, select, type, unpack = pairs, print, select, type, unpack
-- WoW API Functions / Variables
local GetBestMapForUnit,GetContinentMapID,GetMapInfo = C_Map.GetBestMapForUnit,GetContinentMapID,C_Map.GetMapInfo
local GetProfessions, GetProfessionInfo = GetProfessions, GetProfessionInfo

local ATP, Ace3, LSM = unpack(select(2,...))

function Ace3:CheckChildren(continentID,mapID)
	local db = self.db.profile.continents[continentID]

	if (db.children and db.children[mapID]) then
		return db.children[mapID]
	else
		return mapID
	end
end

function Ace3:CopyValues(db,dest,src)
	for k,v in pairs(db) do
		if (type(v) == "table" and k ~= "skills") then
			self:CopyValues(db[k],dest,src)
		elseif (type(v) == "table" and k == "skills") then
			db[k][dest] = db[k][src]
		end
	end
end

function Ace3:GetContinentMapID(mapID)
	local mapInfo = GetMapInfo(mapID)
	local continentID = ""
	
	if (mapID == 1355) then
		-- Nazjatar doesn't belong to a continent.
		-- Skip this process and just return Nazjatar's map ID.
		return tostring(mapID)
	else
		if (mapInfo["mapType"] ~= 2) then
			continentID = self:GetContinentMapID(mapInfo["parentMapID"])
		else
			return tostring(mapInfo["mapID"])
		end
	end
	
	return tostring(continentID)
end

function Ace3:GetLocationIDs()
	local mapID = tostring(GetBestMapForUnit("player"))
	local continentID = self:GetContinentMapID(mapID)

	-- Some maps have children (ie. Shattrath City in Terokkar Forest).
	-- We don't want the child's ID, so get the parent if this is the case.
	mapID = tostring(self:CheckChildren(continentID,mapID))
	
	return continentID,mapID
end

function Ace3:GetNumActiveProfessions()
	local numActive = 0
	local prof1,prof2,_,fishing = GetProfessions()
	
	if (prof1 and (GetProfessionInfo(prof1) == "Herbalism" or GetProfessionInfo(prof1) == "Mining")) then
		numActive = numActive + 1
	end
	
	if (prof2 and (GetProfessionInfo(prof2) == "Herbalism" or GetProfessionInfo(prof2) == "Mining")) then
		numActive = numActive + 1
	end
	
	if (fishing) then
		numActive = numActive + 1
	end
	
	return numActive
end

function Ace3:GetTrackingIDs()
	for i=1,GetNumTrackingTypes() do
		local name = GetTrackingInfo(i)
		
		if (name == "Find Herbs") then
			self.db.char.trackingIDs.herbalism = i
		end
		
		if (name == "Find Minerals") then
			self.db.char.trackingIDs.mining = i
		end
		
		if (name == "Find Fish") then
			self.db.char.trackingIDs.fishing = i
		end
		
		if (name == "Track Pets") then
			self.db.char.trackingIDs.pets = i
		end
	end
end

function Ace3:RefreshConfig()
	local ACFG = LibStub("AceConfigRegistry-3.0")
	local tables = ACFG.tables
	
	foreach(tables,function(k,v)
		ACFG:NotifyChange(k)
	end)
	
end

function Ace3:ToggleAllZones(db,continent,skill)
	for k,v in pairs(db.continents[continent]) do
		if (type(v) == "table" and k ~= "children" and k ~= "skills") then
			db.continents[continent][k].skills[skill] = not db.continents[continent][k].skills[skill]
		end
	end
end

function Ace3:UpdateTracking(continentID,mapID)
	if (mapID == "1355") then
		SetTracking(self.db.char.trackingIDs.herbalism,self.db.profile.continents[continentID].skills.herbalism)
		SetTracking(self.db.char.trackingIDs.mining,self.db.profile.continents[continentID].skills.mining)
		SetTracking(self.db.char.trackingIDs.fishing,self.db.profile.continents[continentID].skills.fishing)
		SetTracking(self.db.char.trackingIDs.pets,self.db.profile.continents[continentID].skills.pets)
	else
		SetTracking(self.db.char.trackingIDs.herbalism,self.db.profile.continents[continentID][mapID].skills.herbalism and self.db.profile.continents[continentID].skills.herbalism)
		SetTracking(self.db.char.trackingIDs.mining,self.db.profile.continents[continentID][mapID].skills.mining and self.db.profile.continents[continentID].skills.mining)
		SetTracking(self.db.char.trackingIDs.fishing,self.db.profile.continents[continentID][mapID].skills.fishing and self.db.profile.continents[continentID].skills.fishing)
		SetTracking(self.db.char.trackingIDs.pets,self.db.profile.continents[continentID][mapID].skills.pets and self.db.profile.continents[continentID].skills.pets)
	end
end