-- *********************************************************
-- **           Sweetsour's Auto Tracker - Core           **
-- **            http://sweetsour.live/discord            **
-- **          https://www.patreon.com/sweetsour          **
-- *********************************************************
--
-- This addon is written and copyrighted by:
--    • Mike Thornton (Sweetsour @ US-Firetree)
--
--
-- The code of this addon is licensed under a Creative Commons Attribution-Noncommercial-Share Alike 3.0 License. (see license.txt)
-- All included textures and sounds are copyrighted by their respective owners, license information for these media files can be found in the modules that make use of them.
--
--
--  You are free:
--    • to Share - to copy, distribute, display, and perform the work
--    • to Remix - to make derivative works
--  Under the following conditions:
--    • Attribution. You must attribute the work in the manner specified by the author or licensor (but not in any way that suggests that they endorse you or your use of the work). (A link to https://www.patreon.com/sweetsour is sufficient)
--    • Noncommercial. You may not use this work for commercial purposes.
--    • Share Alike. If you alter, transform, or build upon this work, you may distribute the resulting work only under the same or similar license to this one.
--

--[[---------------------------------------
	VARIABLE CACHING
-----------------------------------------]]

-- Lua Functions
local pairs, print, select, tostring, type = pairs, print, select, tostring, type
local find = string.find
-- WoW API Functions / Variables
local CreateFrame = CreateFrame
local InterfaceOptionsFrame, InterfaceOptionsFrameAddOns = InterfaceOptionsFrame, InterfaceOptionsFrameAddOns
local UnitAffectingCombat = UnitAffectingCombat
local DEFAULT_CHAT_FRAME = DEFAULT_CHAT_FRAME


local FOLDER_NAME, Engine = ...

local Ace3 = LibStub('AceAddon-3.0'):NewAddon("AutoTracker", 'AceConsole-3.0','AceEvent-3.0');
local AceC = LibStub('AceConsole-3.0')
local LSM = LibStub('LibSharedMedia-3.0')
local GUI = LibStub("AceGUI-3.0")
local GUI = LibStub("AceGUI-3.0")

Ace3.version = GetAddOnMetadata("AutoTracker", 'Version')

local ATP = {
	temp = {
		IsInterfaceOpen = false,
	}
}

Engine[1] = ATP
Engine[2] = Ace3
Engine[3] = LSM

------------------------------
--- For Debugging Purposes ---
------------------------------
local BackdropSB = {
	bgFile   = [[Interface\Tooltips\UI-Tooltip-Background]],
	edgeFile = [[Interface\Tooltips\UI-Tooltip-Border]],
	tile = true,
	tileSize = 16,
	edgeSize = 10
}
ATP.BackdropSB = BackdropSB

local frame = CreateFrame("frame")

local DataFrame = CreateFrame('Frame',nil,UIParent)
DataFrame:SetWidth(700)
DataFrame:SetHeight(300)
DataFrame:SetPoint('TOPLEFT',UIParent,'TOPLEFT',100,-100)
DataFrame:SetBackdrop(BackdropSB)
DataFrame:SetBackdropColor(0.15,0.15,0.15,0.9)
DataFrame:SetBackdropBorderColor(1,1,1,1)
DataFrame:Hide()

DataFrame.text = DataFrame:CreateFontString(nil, 'MEDIUM', 'GameFontHighlightLarge')
DataFrame.text:SetPoint('TOPLEFT',11,-5);
DataFrame.text:SetTextColor(1,1,1,1)
DataFrame.text:SetJustifyH('LEFT')
DataFrame.text:SetFont("Fonts\\FRIZQT__.TTF", 8)

ATP.DataFrame = DataFrame
_G['ATP_DataFrame'] = DataFrame

function Ace3:CurText(name)
	return ATP[name].text:GetText() or ''
end

local function NavigateInterfaceOptions(index,isClick)
	local listIndex

	InterfaceOptionsFrame:Show()
	if (not isClick) then
		InterfaceOptionsFrameTab2:Click()
	end

	for i=2,InterfaceOptionsFrameAddOns:GetNumChildren() do
		if (select(i,InterfaceOptionsFrameAddOns:GetChildren()):GetText() == "AutoTracker") then
			listIndex = i
			listObject = select(i,InterfaceOptionsFrameAddOns:GetChildren())

			if (select((i+1),InterfaceOptionsFrameAddOns:GetChildren()):GetText() ~= "Crit Sounds") then
				if (not isClick) then
					select(1,listObject:GetChildren()):Click()
				end
			end
			break
		end
	end
	
	ATP.temp.IsInterfaceOpen = true
	
	select(listIndex+index,InterfaceOptionsFrameAddOns:GetChildren()):Click()
end

local function ChatCommandParser(input)
	if (UnitAffectingCombat('player')) then
		DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF77Sweetsour\'s Auto Tracker|r: |cFFFF7777You cannot access options while in combat.")
	else
		if not input or input:trim() == "" then
			Ace3:NavigateInterfaceOptions(0,ATP.temp.IsInterfaceOpen)
		elseif input == "herb" or input == "herbing" or input == "herbalism" then
			Ace3:NavigateInterfaceOptions(1,ATP.temp.IsInterfaceOpen)
		elseif input == "mining" then
			Ace3:NavigateInterfaceOptions(2,ATP.temp.IsInterfaceOpen)
		elseif input == "fish" or input == "fishing" then
			Ace3:NavigateInterfaceOptions(3,ATP.temp.IsInterfaceOpen)
		elseif input == "profile" or input == "profiles" then
			Ace3:NavigateInterfaceOptions(4,ATP.temp.IsInterfaceOpen)
		elseif input == "version" then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF77Sweetsour\'s Auto Tracker|r: |cFF9999FF"..GetAddOnMetadata(FOLDER_NAME,"Version").."|r")
		else
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF77Sweetsour\'s Auto Tracker|r: |cFFFF7777Invalid input.")
			DEFAULT_CHAT_FRAME:AddMessage("/|cFFFFFF77sat|r: |cFFFFFFFFOpen addon's home page|r")
			DEFAULT_CHAT_FRAME:AddMessage("/|cFFFFFF77sat|r |cFFBBBBFFherb|r: |cFFFFFFFFOpen Herbalism Window|r")
			DEFAULT_CHAT_FRAME:AddMessage("/|cFFFFFF77sat|r |cFFBBBBFFmining|r: |cFFFFFFFFOpen Mining Window|r")
			DEFAULT_CHAT_FRAME:AddMessage("/|cFFFFFF77sat|r |cFFBBBBFFfishing|r: |cFFFFFFFFOpen Fishing Window|r")
			DEFAULT_CHAT_FRAME:AddMessage("/|cFFFFFF77sat|r |cFFBBBBFFprofile|r: |cFFFFFFFFOpen Profiles Window|r")
		end
	end
end

AceC:RegisterChatCommand("sat",ChatCommandParser)


-- Event: ADDON_LOADED
function Ace3:OnInitialize()
	local about_panel = LibStub:GetLibrary("LibAboutPanel", true)

	if about_panel then
		self.optionsFrame = about_panel.new(nil, "AutoTracker")
	end

	self.db = LibStub("AceDB-3.0"):New("ATP_db", ATP.defaults)
	ATP.profile = self.db.profile
	ATP.char = self.db.char
	
	self:SetupOptions()
end

function Ace3:OnEnable()
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	--self:RegisterEvent("CHAT_MSG_SKILL")
	--self:RegisterEvent("CHAT_MSG_SYSTEM")
	
	self:GetTrackingIDs()
end

function Ace3:ZONE_CHANGED_NEW_AREA()
	local continentID,mapID = self:GetLocationIDs()

	self:UpdateTracking(continentID,mapID)
end

--[[function Ace3:CHAT_MSG_SKILL(e,msg)
	if (msg == "You have gained the Herbalism skill." or msg == "You have gained the Mining skill.") then
		self:RefreshConfig()
		self:SetupOptions()
	end
end]]

--[[function Ace3:CHAT_MSG_SYSTEM(e,msg)
	if (string.find(msg,"You have unlearned") > 0 and string.find(msg,"Herbalism Skills") > 0) then
		self:RefreshConfig()
		self:SetupOptions()
	end
end]]

_G["ATP_private_db"] = ATP
_G["ATP_Ace3_db"] = Ace3